import request from '@/utils/request'
import { IFlowFormInput } from './flowForm'

export enum FlowStatus {
  NOSTART = 0,
  ONGOING = 1,
  SUCCESS = 2,
  REVOKE = 3,
  PART_ERROR = 8,
  ERROR = 9
}

export interface IFlowInstTask {
  taskId: string
  nodeId: string
  name: string
  action?: string
  executors: string[]
  executor?: string
  status: number
  nodeType: number
  startTime: number
  endTime: number
  duration?: number
  comment?: string
}

export interface IFlowInstance {
  _id?: string
  defId: string
  category: string
  name: string
  startUser: string
  startUserName?: string
  startTime?: number
  endTime?: number
  currentId: string
  status: number
  flowData?: any
  comment?: string
  newrecord: boolean
  inputs: IFlowFormInput[]
  tasks: IFlowInstTask[]
}

export const defaultFlowInstance: IFlowInstance = {
  name: '',
  defId: '',
  category: '',
  startUser: '',
  status: 0,
  currentId: '',
  tasks: [],
  inputs: [],
  newrecord: true
}

export const getInstanceFromDef = (id: string) =>
  request({
    url: `/api/flow/pre_instance`,
    method: 'post',
    data: { did: id }
  })

export const queryFlowInstance = (data: any) =>
  request({
    url: '/api/flow/instances',
    method: 'post',
    data
  })

export const myFlowInstance = (data: any) =>
  request({
    url: '/api/flow/myinstlist',
    method: 'post',
    data
  })

export const getFlowInstance = (id: string) =>
  request({
    url: `/api/flow/instance/${id}`,
    method: 'get'
  })

export const saveFlowInstance = (data: any) =>
  request({
    url: '/api/flow/instance',
    method: 'post',
    data
  })

export const updateApproval = (data: any) =>
  request({
    url: '/api/flow/instance/approval',
    method: 'post',
    data
  })
