import router from './router'
import NProgress from 'nprogress'
import 'nprogress/nprogress.css'
import { Message } from 'element-ui'
import { Route, RouteConfig } from 'vue-router'
import { UserModule } from '@/store/modules/user'
import { PermissionModule } from '@/store/modules/permission'
import i18n from '@/lang' // Internationalization
import settings from './settings'
import Layout from '@/layout/index.vue'

NProgress.configure({ showSpinner: false })

const whiteList = ['/login', '/login-admin', '/auth-redirect']

const getPageTitle = (key: string) => {
  const hasKey = i18n.te(`route.${key}`)
  if (hasKey) {
    const pageName = i18n.t(`route.${key}`)
    return `${pageName} - ${settings.title}`
  }
  return `${settings.title}`
}

router.beforeEach(async (to: Route, _: Route, next: any) => {
  // Start progress bar
  NProgress.start()

  // Determine whether the user has logged in
  if (UserModule.token) {
    if (to.path === '/login') {
      // If is logged in, redirect to the home page
      next({ path: '/' })
      NProgress.done()
    } else {
      // Check whether the user has obtained his permission roles
      if (UserModule.roles.length === 0) {
        try {
          // Note: roles must be a object array! such as: ['admin'] or ['developer', 'editor']
          const flowRouter = await UserModule.GetUserInfo()
          const roles = UserModule.roles
          // Generate accessible routes map based on role
          // TODO:: 根据实际接口返回, 删除测试数据
          const extRouter: RouteConfig = {
            path: '/system1',
            component: Layout,
            meta: {
              title: 'flow_begin',
              icon: 'component',
              alwaysShow: true
            },
            children: []
          }
          extRouter.children?.push({
            path: 'flow_begin',
            component: () => import('@/views/error-page/401.vue'),
            name: 'FlowBegin',
            meta: {
              title: 'flow_begin',
              permissions: ['flow_exec:read'],
              icon: 'game'
            }
          })
          flowRouter.forEach((o: any) => {
            extRouter.children?.push(o)
          })

          PermissionModule.GenerateRoutes({ extRouter, roles })
          // Dynamically add accessible routes
          // router.addRoutes(PermissionModule.dynamicRoutes)
          PermissionModule.dynamicRoutes.forEach(function(route) {
            router.addRoute(route)
          })
          console.log('add router success: ', router.getRoutes())
          // Hack: ensure addRoutes is complete
          // Set the replace: true, so the navigation will not leave a history record
          next({ ...to, replace: true })
        } catch (err) {
          // Remove token and redirect to login page
          UserModule.ResetToken()
          Message.error(err || 'Has Error')
          next(`/login?redirect=${to.path}`)
          NProgress.done()
        }
      } else {
        next()
      }
    }
  } else {
    // Has no token
    if (whiteList.indexOf(to.path) !== -1) {
      // In the free login whitelist, go directly
      next()
    } else {
      // Other pages that do not have permission to access are redirected to the login page.
      next(`/login?redirect=${to.path}`)
      NProgress.done()
    }
  }
})

router.afterEach((to: Route) => {
  // Finish progress bar
  // hack: https://github.com/PanJiaChen/vue-element-admin/pull/2939
  NProgress.done()

  // set page title
  document.title = getPageTitle(to.meta.title)
})
