import { RouteConfig } from 'vue-router'
import Layout from '@/layout/index.vue'

const flowRoutes: RouteConfig = {
  path: '/flow',
  component: Layout,
  meta: {
    title: 'flow_system',
    icon: 'workflow',
    permissions: ['flow:*'],
    alwaysShow: true
  },
  children: [
    {
      path: 'flow_begin',
      component: () => import('@/views/flow/flowDefList.vue'),
      name: 'FlowBegin',
      meta: {
        title: 'flow_begin',
        permissions: ['instance:read', 'flow:exec'],
        icon: 'game'
      }
    },
    {
      path: 'mylist',
      component: () => import('@/views/flow/myFlowList.vue'),
      name: 'MyFlowList',
      meta: {
        title: 'my_flow_list',
        permissions: ['instance:read', 'flow:exec'],
        icon: 'game'
      }
    },
    {
      path: 'flow_ongoing',
      name: 'FlowGoing',
      redirect: '/flow/list/1',
      meta: {
        title: 'flow_going',
        permissions: ['instance:read'],
        icon: 'game'
      }
    },
    {
      path: 'flow_history',
      name: 'FlowHistory',
      redirect: '/flow/list/2',
      meta: {
        title: 'flow_history',
        permissions: ['instance:read'],
        icon: 'game'
      }
    },
    {
      path: 'list/:status',
      component: () => import('@/views/flow/flowList.vue'),
      name: 'FlowList',
      meta: {
        title: 'flow_list',
        permissions: ['instance:read', 'flow:exec'],
        icon: 'game',
        hidden: true
      }
    },
    {
      path: 'begin/:id',
      component: () => import('@/views/flow/flowBegin.vue'),
      name: 'FlowBegin',
      meta: {
        title: 'start_flow',
        permissions: ['instance:read', 'flow:exec'],
        icon: 'game',
        hidden: true
      }
    },
    {
      path: 'view/:id',
      component: () => import('@/views/flow/flowView.vue'),
      name: 'FlowView',
      meta: {
        title: 'flow_view',
        permissions: ['instance:read', 'flow:exec'],
        icon: 'game',
        hidden: true
      }
    }
  ]
}

export default flowRoutes
