import { RouteConfig } from 'vue-router'
import Layout from '@/layout/index.vue'

const flowDefRoutes: RouteConfig = {
  path: '/flow_def',
  component: Layout,
  meta: {
    title: 'flow_manage',
    icon: 'workflow',
    permissions: ['definition:*'],
    alwaysShow: true
  },
  children: [
    {
      path: 'flow_defs',
      component: () => import('@/views/flow/def/list.vue'),
      name: 'flowDefList',
      meta: {
        title: 'flow_def_list',
        permissions: ['definition:read'],
        icon: 'flow_setting'
      }
    },
    {
      path: 'create_def',
      component: () => import('@/views/flow/def/form.vue'),
      name: 'Createflow',
      meta: {
        title: 'create_flow_def',
        permissions: ['definition:edit'],
        icon: 'edit',
        hidden: true
      }
    },
    {
      path: 'edit_def/:id',
      component: () => import('@/views/flow/def/form.vue'),
      name: 'flowEditor',
      meta: {
        title: 'edit_flow_def',
        permissions: ['definition:read', 'definition:edit'],
        elicon: 'el-icon-arrow-right',
        hidden: true
      }
    },
    {
      path: 'flow_category',
      component: () => import('@/views/flow/category/list.vue'),
      name: 'FlowCategory',
      meta: {
        title: 'flow_category',
        permissions: ['category:read'],
        icon: 'game'
      }
    },
    {
      path: 'cate_new',
      component: () => import('@/views/flow/category/form.vue'),
      name: 'CreateFlowCate',
      meta: {
        title: 'create_cate',
        icon: 'edit',
        permissions: ['category:edit'],
        hidden: true
      }
    },
    {
      path: 'cate_edit/:id',
      component: () => import('@/views/flow/category/form.vue'),
      name: 'FlowCateEditor',
      meta: {
        title: 'edit_cate',
        permissions: ['category:read', 'category:edit'],
        elicon: 'el-icon-arrow-right',
        hidden: true
      }
    },
    {
      path: 'flow_node_list',
      component: () => import('@/views/flow/flownode/list.vue'),
      name: 'FlowNodes',
      meta: {
        title: 'flow_node_list',
        permissions: ['node:read'],
        icon: 'game'
      }
    },
    {
      path: 'flow_node_new',
      component: () => import('@/views/flow/flownode/form.vue'),
      name: 'CreateFlowNode',
      meta: {
        title: 'create_flow_node',
        icon: 'edit',
        permissions: ['node:edit'],
        hidden: true
      }
    },
    {
      path: 'flow_node_edit/:id',
      component: () => import('@/views/flow/flownode/form.vue'),
      name: 'FlowNodeEditor',
      meta: {
        title: 'edit_flow_node',
        permissions: ['node:read', 'node:edit'],
        elicon: 'el-icon-arrow-right',
        hidden: true
      }
    },
    {
      path: 'flow_form_list',
      component: () => import('@/views/flow/flowform/list.vue'),
      name: 'FlowForms',
      meta: {
        title: 'flow_form_list',
        permissions: ['form:read'],
        icon: 'game'
      }
    },
    {
      path: 'flow_form_new',
      component: () => import('@/views/flow/flowform/form.vue'),
      name: 'CreateFlowForm',
      meta: {
        title: 'create_flow_form',
        icon: 'edit',
        permissions: ['form:edit'],
        hidden: true
      }
    },
    {
      path: 'flow_form_edit/:id',
      component: () => import('@/views/flow/flowform/form.vue'),
      name: 'EditFlowForm',
      meta: {
        title: 'edit_flow_form',
        permissions: ['form:read', 'form:edit'],
        elicon: 'el-icon-arrow-right',
        hidden: true
      }
    }
  ]
}

export default flowDefRoutes
