import { RouteConfig } from 'vue-router'
import Layout from '@/layout/index.vue'

const systemRoutes: RouteConfig = {
  path: '/system',
  component: Layout,
  redirect: '/system/list',
  meta: {
    title: 'system',
    icon: 'component',
    permissions: ['shopman:*', 'permission:*', 'admin:*', 'role:*'],
    alwaysShow: true
  },
  children: [
    {
      path: 'permission',
      component: () => import('@/views/system/permission.vue'),
      name: 'Permission',
      meta: {
        title: 'permission',
        permissions: ['permission:read'],
        icon: 'permission'
      }
    },
    {
      path: 'role',
      component: () => import('@/views/system/role.vue'),
      name: 'RolePermission',
      meta: {
        title: 'rolePermission',
        permissions: ['role:read'],
        icon: 'role'
      }
    },
    {
      path: 'admin',
      component: () => import('@/views/system/admin.vue'),
      name: 'AdminPermission',
      meta: {
        title: 'adminuser',
        permissions: ['admin:read'],
        icon: 'admin'
      }
    },
    {
      path: 'list',
      component: () => import('@/views/shop/list.vue'),
      name: 'ShopList',
      meta: {
        title: 'shop_list',
        permissions: ['shopman:read'],
        icon: 'shop_list'
      }
    },
    {
      path: 'create',
      component: () => import('@/views/shop/edit.vue'),
      name: 'CreateShop',
      meta: {
        title: 'create_shop',
        icon: 'edit',
        hidden: true,
        permissions: ['shopman:edit']
      }
    },
    {
      path: 'edit/:id',
      component: () => import('@/views/shop/edit.vue'),
      name: 'ShopEditor',
      meta: {
        title: 'shop_edit',
        permissions: ['shopman:edit'],
        elicon: 'el-icon-arrow-right',
        hidden: true
      }
    },
    {
      path: 'i18n',
      component: () => import(/* webpackChunkName: "i18n-demo" */ '@/views/i18n-demo/index.vue'),
      name: 'I18n',
      meta: {
        title: 'i18n',
        icon: 'language',
        permissions: ['show:language']
      }
    },
    {
      path: 'theme',
      component: () => import(/* webpackChunkName: "theme" */ '@/views/theme/index.vue'),
      name: 'Theme',
      meta: {
        title: 'theme',
        icon: 'theme',
        permissions: ['show:theme']
      }
    }
  ]
}

export default systemRoutes
