// Parse the time to string
export const parseTime = (
  time?: object | string | number | null,
  cFormat?: string
): string | null => {
  if (time === undefined || !time) {
    return null
  }
  const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
  let date: Date
  if (typeof time === 'object') {
    date = time as Date
  } else {
    if (typeof time === 'string') {
      if (/^[0-9]+$/.test(time)) {
        // support "1548221490638"
        time = parseInt(time)
      } else {
        // support safari
        // https://stackoverflow.com/questions/4310953/invalid-date-in-safari
        // time = time.replace(new RegExp(/-/gm), '/')
      }
    }
    if (typeof time === 'number' && time.toString().length === 10) {
      time = time * 1000
    }
    date = new Date(time)
  }
  const formatObj: { [key: string]: number } = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  return format.replace(/{([ymdhisa])+}/g, (result, key) => {
    const value = formatObj[key]
    // Note: getDay() returns 0 on Sunday
    if (key === 'a') {
      return ['日', '一', '二', '三', '四', '五', '六'][value]
    }
    return value.toString().padStart(2, '0')
  })
}
/**
 * 将秒数格式化成 小时:分钟:秒
 * @param {number} sec
 * @param showSeconds 是否显示秒
 */
export const sec2TimeStr = (sec: number, showSeconds = true) => {
  showSeconds = typeof showSeconds !== 'undefined' ? showSeconds : true
  const t = sec % 60
  const i = (sec % 3600 - t) / 60
  const n = Math.floor(sec / 3600)
  if (showSeconds) {
    return (n > 9 ? '' + n : '0' + n) + ':' + (i > 9 ? i : '0' + i) + ':' + (t > 9 ? t : '0' + t)
  } else {
    return (n > 9 ? '' + n : '0' + n) + ':' + (i > 9 ? i : '0' + i)
  }
}
/**
 * 将 小时:分钟:秒 格式的字符串转换为秒数
 * @param {string} str
 */
export const timeStr2Sec = (str: string) => {
  const vals = str.split(':')
  const h = vals.length > 0 ? +vals[0] : 0
  const m = vals.length > 1 ? +vals[1] : 0
  const s = vals.length > 2 ? +vals[2] : 0
  return h * 3600 + m * 60 + s
}

// Format and filter json data using filterKeys array
export const formatJson = (filterKeys: any, jsonData: any) =>
  jsonData.map((data: any) => filterKeys.map((key: string) => {
    if (key === 'timestamp') {
      return parseTime(data[key])
    } else {
      return data[key]
    }
  }))

// Check if an element has a class
export const hasClass = (ele: HTMLElement, className: string) => {
  return !!ele.className.match(new RegExp('(\\s|^)' + className + '(\\s|$)'))
}

// Add class to element
export const addClass = (ele: HTMLElement, className: string) => {
  if (!hasClass(ele, className)) ele.className += ' ' + className
}

// Remove class from element
export const removeClass = (ele: HTMLElement, className: string) => {
  if (hasClass(ele, className)) {
    const reg = new RegExp('(\\s|^)' + className + '(\\s|$)')
    ele.className = ele.className.replace(reg, ' ')
  }
}

// Toggle class for the selected element
export const toggleClass = (ele: HTMLElement, className: string) => {
  if (!ele || !className) {
    return
  }
  let classString = ele.className
  const nameIndex = classString.indexOf(className)
  if (nameIndex === -1) {
    classString += '' + className
  } else {
    classString =
      classString.substr(0, nameIndex) +
      classString.substr(nameIndex + className.length)
  }
  ele.className = classString
}

export const delay = (sec: number) => {
  return new Promise((resolve, reject) => {
    setTimeout(function() {
      resolve && resolve('')
    }, sec * 1000)
  })
}

export const getParameter = (t: string) => {
  const e = window.location.hash || ''
  const i = new RegExp(t + '=([^&?]*)', 'ig')
  return e.match(i) ? e.match(i)![0].substr(t.length + 1) : null
}
